S3PartUploaded class

Emitted when an S3 multipart upload part is completed.

This is a plugin-specific event. Core events are defined in lib/src/core/events.dart. Plugin events extend FluppyEvent to integrate with the main event stream.

Inheritance

Constructors

S3PartUploaded(FluppyFile file, S3Part part, int totalParts)
const

Properties

file FluppyFile
The file associated with this event.
final
hashCode int
The hash code for this object.
no setterinherited
part S3Part
The S3 part that was uploaded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalParts int
Total number of parts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited