UploadPartBytesOptions class

Options for uploading part bytes.

Used by UploadPartBytesCallback to provide all necessary information for uploading a part.

Constructors

UploadPartBytesOptions({required String url, String method = 'PUT', Map<String, String>? headers, required Uint8List body, required int size, int? expires, CancellationToken? signal, void onProgress(int bytesUploaded, int bytesTotal)?, void onComplete(String eTag)?})
const

Properties

body Uint8List
The data to upload.
final
expires int?
Optional expiration time in seconds.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
Headers to include in the request.
final
method String
The method to use ('PUT' or 'POST').
final
onComplete → void Function(String eTag)?
Called when upload completes successfully.
final
onProgress → void Function(int bytesUploaded, int bytesTotal)?
Progress callback.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal CancellationToken?
Cancellation signal.
final
size int
Size of the data being uploaded.
final
url String
The presigned URL to upload to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited