AllUploadsComplete class
Emitted when all uploads in the queue are complete.
- Inheritance
-
- Object
- FluppyEvent
- AllUploadsComplete
Constructors
-
AllUploadsComplete(List<
FluppyFile> successful, List<FluppyFile> failed) -
const
Properties
-
failed
→ List<
FluppyFile> -
Files that failed to upload.
final
- file → FluppyFile
-
Dummy file for this event - use successful and failed instead.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
successful
→ List<
FluppyFile> -
Files that uploaded successfully.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited